.. ngsxfem documentation master file, created by
   copy+paste and changes from ngsxtrefftz.

.. raw:: html

    <style>
        .p-Widget {
            height: 400px;
        }
        .dg.main {
            margin-left: 0px;
        }
        div.p-Widget div div div div.dg ul li {
            list-style: none;
            margin-left: 0px;
        }
        div.p-Widget div div div div.dg ul li div.dg {
            margin-bottom: 0px;
        }
    </style>

.. only:: html
    .. role:: raw-html(raw)
        :format: html


.. toctree::
   :caption: Introduction

   index

   xfem_misc/feature-details

.. toctree::
   :caption: Installation

   xfem_misc/installation

.. toctree::
   :caption: Demos / jupyter tutorials
   :maxdepth: 1

   xfem_misc/demos

   jupyter/index.rst

.. toctree::
   :caption: Python interface

   xfem_doc/xfem

.. toctree::
   :caption: Literature

   xfem_misc/paper

   xfem_misc/literature

.. toctree::
   :caption: Indices
